@@ -6,6 +6,6 @@ and add backtracking chat on the basis of pyChatGPT
 '''
 
 
-from .pyChatGPT import ChatGPT
+from .pyChatGPTLoop import ChatGPT
 
 __all__ = ['ChatGPT']
